#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.1.3
visibility:           public
id:                   network-control-0.1.3-D68AUvva2dnHrhsn4BZCbs
key:                  network-control-0.1.3-D68AUvva2dnHrhsn4BZCbs
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  353279c05fbc2941df93a96cde1e6840
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.1.3-D68AUvva2dnHrhsn4BZCbs
depends:
    base-4.18.2.1 psqueues-0.2.8.3-J6Qu2i6p5yH168Q7o34Srt
    unix-time-0.4.17-15h04tU2l2CC3Q9PSvLXPM

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

